Function compile_and_link

pub fn compile_and_link(
    driver_options: DriverOptions,
    source_filenames: &Vec<String>,
) -> Result<String, MultiFileError>
Compiles the given set of source files into object files and then links them together to produce an executable binary file.

Returns the linked executable filename on success, or an error.